==> qtjambi-qt3drender-6.5.6-sources.jar: io/qt/qt3d/render/QStencilTest.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Specifies arguments for the stecil test</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html">Qt3DRender::QStencilTest</a></code></p>
 */
public class QStencilTest extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilTest.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html#QStencilTest">Qt3DRender::QStencilTest::<wbr/>QStencilTest(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilTest(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilTest instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QStencilTest(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QStencilTest(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QStencilTest instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QStencilTest(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilTest() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QStencilTest.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Specifies arguments for the stecil test</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html">Qt3DRender::QStencilTest</a></code></p>
 */
public class QStencilTest extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilTest.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html#QStencilTest">Qt3DRender::QStencilTest::<wbr>QStencilTest(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilTest(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilTest instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QStencilTest(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QStencilTest(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QStencilTest instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QStencilTest(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilTest() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
